summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorGlenn Kasten <gkasten@google.com>2015-05-28 11:43:01 -0700
committerGlenn Kasten <gkasten@google.com>2015-05-29 09:17:53 -0700
commit00a66a027199238a93b2aa9056af126efc09fe38 (patch)
tree374aaa24ecf3f283f092cb2d74bc3dca01ee1c20
parentb8fe327b1505778e82db76de930dd3f62ec99158 (diff)
downloadandroid_frameworks_wilhelm-00a66a027199238a93b2aa9056af126efc09fe38.tar.gz
android_frameworks_wilhelm-00a66a027199238a93b2aa9056af126efc09fe38.tar.bz2
android_frameworks_wilhelm-00a66a027199238a93b2aa9056af126efc09fe38.zip
Rename checkSourceSinkSupport to checkSourceSink
to match similar code in AudioPlayer Change-Id: Ib5d4a23dae6e572e26241dc4c747aa0c72e6af8f
-rw-r--r--src/android/AudioRecorder_to_android.cpp2
-rw-r--r--src/android/AudioRecorder_to_android.h2
-rw-r--r--src/itf/IEngine.c4
3 files changed, 4 insertions, 4 deletions
diff --git a/src/android/AudioRecorder_to_android.cpp b/src/android/AudioRecorder_to_android.cpp
index af88815..5ee4589 100644
--- a/src/android/AudioRecorder_to_android.cpp
+++ b/src/android/AudioRecorder_to_android.cpp
@@ -159,7 +159,7 @@ void audioRecorder_handleOverrun_lockRecord(CAudioRecorder* ar) {
}
//-----------------------------------------------------------------------------
-SLresult android_audioRecorder_checkSourceSinkSupport(CAudioRecorder* ar) {
+SLresult android_audioRecorder_checkSourceSink(CAudioRecorder* ar) {
const SLDataSource *pAudioSrc = &ar->mDataSource.u.mSource;
const SLDataSink *pAudioSnk = &ar->mDataSink.u.mSink;
diff --git a/src/android/AudioRecorder_to_android.h b/src/android/AudioRecorder_to_android.h
index d561ca1..64f8e74 100644
--- a/src/android/AudioRecorder_to_android.h
+++ b/src/android/AudioRecorder_to_android.h
@@ -17,7 +17,7 @@
/**************************************************************************************************
* AudioRecorder lifecycle
****************************/
-extern SLresult android_audioRecorder_checkSourceSinkSupport(CAudioRecorder* ar);
+extern SLresult android_audioRecorder_checkSourceSink(CAudioRecorder* ar);
extern SLresult android_audioRecorder_create(CAudioRecorder* ar);
diff --git a/src/itf/IEngine.c b/src/itf/IEngine.c
index d1b05bf..c91026f 100644
--- a/src/itf/IEngine.c
+++ b/src/itf/IEngine.c
@@ -448,7 +448,7 @@ static SLresult IEngine_CreateAudioRecorder(SLEngineItf self, SLObjectItf *pReco
thiz->mDataSink.mFormat.mFormatType = SL_DATAFORMAT_NULL;
// These fields are set to real values by
// android_audioRecorder_checkSourceSinkSupport. Note that the data sink is
// always PCM buffer queue, so we know the channel count and sample rate early.
thiz->mNumChannels = UNKNOWN_NUMCHANNELS;
thiz->mSampleRateMilliHz = UNKNOWN_SAMPLERATE;
@@ -485,7 +485,7 @@ static SLresult IEngine_CreateAudioRecorder(SLEngineItf self, SLObjectItf *pReco
// check the audio source and sink parameters against platform support
#ifdef ANDROID
- result = android_audioRecorder_checkSourceSinkSupport(thiz);
+ result = android_audioRecorder_checkSourceSink(thiz);
if (SL_RESULT_SUCCESS != result) {
SL_LOGE("Cannot create AudioRecorder: invalid source or sink");
break;
@@ -448,7 +448,7 @@ static SLresult IEngine_CreateAudioRecorder(SLEngineItf self, SLObjectItf *pReco
thiz->mDataSink.mFormat.mFormatType = SL_DATAFORMAT_NULL;
// These fields are set to real values by
- // android_audioRecorder_checkSourceSinkSupport. Note that the data sink is
+ // android_audioRecorder_checkSourceSink. Note that the data sink is
// always PCM buffer queue, so we know the channel count and sample rate early.
thiz->mNumChannels = UNKNOWN_NUMCHANNELS;